=== modified file 'breezy/plugins/gitlab/hoster.py'
--- breezy/plugins/gitlab/hoster.py	2020-10-22 17:33:25 +0000
+++ breezy/plugins/gitlab/hoster.py	2020-10-22 21:54:13 +0000
@@ -20,6 +20,7 @@
 
 import json
 import os
+import re
 import time
 
 from ... import (
@@ -125,8 +126,11 @@
         self.project = project
 
 
-class MergeRequestExists(Exception):
-    """Raised when a merge requests already exists."""
+class MergeRequestConflict(Exception):
+    """Raised when a merge requests conflicts."""
+
+    def __init__(self, reason):
+        self.reason = reason
 
 
 class ProjectCreationTimeout(errors.BzrError):
@@ -528,7 +532,7 @@
         if response.status == 403:
             raise errors.PermissionDenied(response.text)
         if response.status == 409:
-            raise MergeRequestExists()
+            raise MergeRequestConflict(json.loads(response.data))
         if response.status == 422:
             data = json.loads(response.data)
             raise GitLabUnprocessable(data['error'])
@@ -755,8 +759,18 @@
                 kwargs['assignee_ids'].append(user['id'])
         try:
             merge_request = self.gl._create_mergerequest(**kwargs)
-        except MergeRequestExists:
-            raise MergeProposalExists(self.source_branch.user_url)
+        except MergeRequestConflict as e:
+            m = re.fullmatch(
+                r'Another open merge request already exists for '
+                r'this source branch: \!([0-9]+)',
+                e.reason['message'][0])
+            if m:
+                merge_id = int(m.group(1))
+                mr = self.gl._get_merge_request(
+                    target_project['path_with_namespace'], merge_id)
+                raise MergeProposalExists(
+                    self.source_branch.user_url, GitLabMergeProposal(self.gl, mr))
+            raise Exception('conflict: %r' % e.reason)
         except GitLabUnprocessable as e:
             if e.error == [
                     "Source project is not a fork of the target project"]:

=== modified file 'breezy/propose.py'
--- breezy/propose.py	2020-09-09 23:16:31 +0000
+++ breezy/propose.py	2020-10-22 21:54:13 +0000
@@ -39,9 +39,10 @@
 
     _fmt = "A merge proposal already exists: %(url)s."
 
-    def __init__(self, url):
+    def __init__(self, url, existing_proposal=None):
         errors.BzrError.__init__(self)
         self.url = url
+        self.existing_proposal = existing_proposal
 
 
 class UnsupportedHoster(errors.BzrError):

